@@ -14,21 +14,26 @@
 #' followed by a `geom_treemap_subgroup2_border` layer, the second layer will
 #' be drawn on top of the first and may hide it.
 #'
-#' The `fixed` argument is used to set the treemap layout algorithm. All
-#' `treemapify` geoms added to a plot should have the same value for `fixed`,
-#' or they will not share a common layout (see `geom_treemap` for details on
-#' the layout algorithms).
+#' The `layout` argument is used to set the treemap layout algorithm. All
+#' `treemapify` geoms added to a plot should have the same value for `layout`
+#' and `start`, or they will not share a common layout (see `geom_treemap` for
+#' details on the layout algorithms).
 #'
 #' @seealso geom_treemap, geom_treemap_subgroup_text
 #'
 #' @param mapping,data,stat,position,na.rm,show.legend,inherit.aes,... Standard
 #' geom arguments as for `ggplot2::geom_rect`.
-#' @param fixed If `TRUE`, the alternative 'fixed' tile layout algorithm will be
-#' used.
+#' @param layout The layout algorithm, one of either "squarified" (the
+#' default), "scol", "srow" or "fixed". See Details for full details on the
+#' different layout algorithms.
+#' @param start The corner in which to start placing the tiles. One of
+#' 'bottomleft' (the default), 'topleft', 'topright' or 'bottomright'.
 #' @param level One of 'subgroup', 'subgroup2' or 'subgroup3', giving the
 #' subgrouping level for which to draw borders. It is recommended to use the
 #' aliases `geom_treemap_subgroup2_border` and `geom_treemap_subgroup3_border`
 #' instead of this argument.
+#' @param fixed Deprecated. Use `layout = "fixed"` instead. Will be removed in
+#' later versions.
 #'
 #' @section Aesthetics:
 #'
@@ -58,7 +63,9 @@ geom_treemap_subgroup_border <- function(
   na.rm = FALSE,
   show.legend = NA,
   inherit.aes = TRUE,
-  fixed = F,
+  fixed = NULL,
+  layout = "squarified",
+  start = "bottomleft",
   level = "subgroup",
   ...
 ) {
@@ -73,6 +80,8 @@ geom_treemap_subgroup_border <- function(
     params = list(
       na.rm = na.rm,
       fixed = fixed,
+      layout = layout,
+      start = start,
       level = level,
       ...
     )
@@ -98,7 +107,9 @@ GeomSubgroupBorder <- ggplot2::ggproto(
     data,
     panel_scales,
     coord,
-    fixed = F,
+    fixed = NULL,
+    layout = "squarified",
+    start = "bottomleft",
     level = "subgroup"
   ) {
 
@@ -108,14 +119,16 @@ GeomSubgroupBorder <- ggplot2::ggproto(
     levels <- c("subgroup", "subgroup2", "subgroup3")
     if (!level %in% levels) {
       stop(
-        "`level` argument must be one of 'subgroup', 'subgroup2' or 'subgroup3'",
-        call. = F
+        "`level` must be one of 'subgroup', 'subgroup2' or 'subgroup3'",
+        call. = FALSE
       )
     }
     if (!level %in% names(data)) {
       stop(
-        "Can't draw a border for subgroup level ", level, " as it is not a plot aesthetic",
-        call. = F
+        "Can't draw a border for subgroup level ", 
+        level, 
+        " as it is not a plot aesthetic", 
+        call. = FALSE
       )
     }
 
@@ -134,7 +147,9 @@ GeomSubgroupBorder <- ggplot2::ggproto(
     params <- list(
       data = data,
       area = "area",
-      fixed = fixed
+      fixed = fixed,
+      layout = layout,
+      start = start
     )
     for (l in levels[1:(length(levels) - 1)]) { params[l] <- l }
     data <- do.call(treemapify, params)
